@@ -3,7 +3,7 @@ from asyncio import Queue
 from typing import Callable, List, Iterator
 
 from rx import Observable
-from rx.subjects import Subject
+from rx.subject import Subject
 
 from interstate_py.log_factory import LogFactory
 from interstate_py.reactive.rx_stream_connection import RxStreamConnection
@@ -47,9 +47,9 @@ class RxConnectionAgent(ConnectionAgentBase):
     """
     _log = LogFactory.get_logger(__name__)
 
-    def __init__(self, supplier: Callable[[Subject], Observable], outbound_queue: Queue):
+    def __init__(self, evaluation_fn: Callable[[Subject], Observable], outbound_queue: Queue):
         self._connections = {}
-        self._supplier = supplier
+        self._evaluation_fn = evaluation_fn
         self._outbound_queue = outbound_queue
 
     def get(self, identity: str) -> StreamConnection:
@@ -57,10 +57,10 @@ class RxConnectionAgent(ConnectionAgentBase):
             return self._connections.get(identity)
         else:
             subject = Subject()
-            outbound = self._supplier(subject)
+            outbound = self._evaluation_fn(subject)
             outbound \
                 .subscribe(SendingObserver(identity, self._outbound_queue))
-            self._log.info("[CONTROL] Added new connection (identity=%s)", identity)
+            self._log.debug("[CONTROL] Added new connection (identity=%s)", identity)
             connection = RxStreamConnection(identity, subject, outbound)
             self._connections[identity] = connection
             return connection
