@@ -2,8 +2,9 @@ import asyncio
 from asyncio import Future, Queue
 from typing import Any
 
-from rx import Observer
+from rx.core.typing import Observer
 
+from interstate_py.error.error_assembly import InterstateError, ErrorAssembly
 from interstate_py.interstate_message import InterstateWireMessage, InterstateWireMessageType
 from interstate_py.log_factory import LogFactory
 from interstate_py.multiplex_message import MultiplexMessage
@@ -21,13 +22,20 @@ class SendingObserver(Observer):
         self._outbound_queue = outbound_queue
 
     def on_next(self, value):
-        self._dispatch_internal(MultiplexMessage(
-            self._identity, InterstateWireMessageType.NEXT, value
-        ))
+        if value is None:
+            self.on_error(Exception("The evaluate function returned 'None'"))
+        else:
+            self._dispatch_internal(MultiplexMessage(
+                self._identity, InterstateWireMessageType.NEXT, value
+            ))
 
     def on_error(self, error):
         self._dispatch_internal(MultiplexMessage(
-            self._identity, InterstateWireMessageType.ERROR, error
+            self._identity, InterstateWireMessageType.ERROR,
+            InterstateError(error.__class__.__name__,
+                            ErrorAssembly.exc_message(error),
+                            ErrorAssembly.get_stacktrace(50)
+                        )
         ))
 
     def on_completed(self):
